OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Přidáno do oblíbených",
    "Removed from favorites" : "Odebráno z oblíbených",
    "You added {file} to your favorites" : "Do svých oblíbených jste přidali {file}",
    "You removed {file} from your favorites" : "Odstranili jste {file} ze svých oblíbených",
    "Favorites" : "Oblíbené",
    "File changes" : "Změny souboru",
    "Created by {user}" : "Vytvořil(a) {user}",
    "Changed by {user}" : "Změnil(a) {user}",
    "Deleted by {user}" : "Odstranil(a) {user}",
    "Restored by {user}" : "Obnovil(a) {user}",
    "Renamed by {user}" : "Přejmenováno uživatelem {user}",
    "Moved by {user}" : "Přesunuto uživatelem {user}",
    "\"remote account\"" : "„vzdálený účet“",
    "You created {file}" : "Vytvořili jste {file}",
    "You created an encrypted file in {file}" : "Vytvořili jste šifrovaný soubor v {file}",
    "{user} created {file}" : "{user} vytvořil(a) {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvořil(a) šifrovaný soubor v {file}",
    "{file} was created in a public folder" : "Soubor {file} byl vytvořen ve veřejné složce",
    "You changed {file}" : "Změnili jste {file}",
    "You changed an encrypted file in {file}" : "Změnili jste šifrovaný soubor v {file}",
    "{user} changed {file}" : "{user} změnil(a) {file}",
    "{user} changed an encrypted file in {file}" : "{user} změnil(a) šifrovaný soubor v {file}",
    "You deleted {file}" : "Odstranili jste {file}",
    "You deleted an encrypted file in {file}" : "Smazali jste šifrovaný soubor v {file}",
    "{user} deleted {file}" : "{user} smazal(a) {file}",
    "{user} deleted an encrypted file in {file}" : "{user} smazal(a) šifrovaný soubor v {file}",
    "You restored {file}" : "Obnovili jste {file}",
    "{user} restored {file}" : "{user} obnovil(a) {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Přejmenovali jste {oldfile} (hidden) na {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Přejmenovali jste {oldfile} (hidden) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Přejmenovali jste {oldfile} na {newfile} (hidden)",
    "You renamed {oldfile} to {newfile}" : "Přejmenovali jste {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} přejmenoval(a) {oldfile} (skrytý) na {newfile} (skrytý)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} přejmenoval(a) {oldfile} (skrytý) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} přejmenoval(a) {oldfile} na {newfile} (skrytý)",
    "{user} renamed {oldfile} to {newfile}" : "{user} přejmenoval(a) {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Přesunuli jste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} přesunul(a) {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Soubor byl přidán, nebo odstraněn z vašich <strong>oblíbených</strong>",
    "Files" : "Soubory",
    "A file or folder has been <strong>changed</strong>" : "Soubor nebo složka byla <strong>změněna</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Oblíbený soubor nebo složka byla <strong>změněna</strong>",
    "Failed to authorize" : "Nepodařilo se získat pověření",
    "Invalid folder path" : "Neplatný popis umístění složky",
    "Folder not found" : "Složka nenalezena",
    "The file cannot be found" : "Soubor není možné nalézt",
    "The destination path does not exist: %1$s" : "Cílový popis umístění neexistuje: %1$s",
    "You do not have permission to create a file at the specified location" : "Nemáte oprávnění pro vytvoření souboru v určeném umístění",
    "The file could not be converted." : "Soubor nebylo možné převést.",
    "Could not get relative path to converted file" : "Nepodařilo se získat vztažený popis umístění převáděného souboru",
    "Favorite files" : "Oblíbené soubory",
    "No favorites" : "Žádné oblíbené",
    "More favorites" : "Další oblíbené",
    "Upload (max. %s)" : "Nahrát (max. %s)",
    "Accept" : "Přijmout",
    "Reject" : "Odmítnout",
    "Incoming ownership transfer from {user}" : "Příchozí převedení vlastnictví od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete přijmout {path}?\n\nPozn.: Proces převedení může trvat až hodinu po přijmutí.",
    "Ownership transfer denied" : "Převedení vlastnictví odepřeno",
    "Your ownership transfer of {path} was denied by {user}." : "Převedení vašeho vlastnictví {path} bylo odepřeno {user}.",
    "Ownership transfer failed" : "Převedení vlastnictví se nezdařilo",
    "Your ownership transfer of {path} to {user} failed." : "Převedení vlastnictví {path} od vás na {user} se nezdařilo.",
    "The ownership transfer of {path} from {user} failed." : "Převedení vlastnictví {path} od {user} se nezdařilo.",
    "Ownership transfer done" : "Převedení vlastnictví dokončeno",
    "Your ownership transfer of {path} to {user} has completed." : "Převedení vámi vlastněného {path} na {user} dokončeno.",
    "The ownership transfer of {path} from {user} has completed." : "Převedení vlastnictví {path} od {user} dokončeno.",
    "in %s" : "v %s",
    "Transferred from %1$s on %2$s" : "Převedeno z %1$s na %2$s",
    "Files compatibility" : "Kompatibilita souborů",
    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "Umožňuje omezit názvy souborů aby bylo zajištěno, že soubory bude možné synchronizovat se všemi klienty. Ve výchozím stavu jsou povoleny veškeré názvy souborů, splňující standard POSIX (např. Linux nebo macOS).",
    "Enforce Windows compatibility" : "Vynutit kompatibilitu s Windows",
    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "Toto bude blokovat použití názvů souborů, které nejsou platné na strojích s Windows, jako je použití vyhrazených názvů nebo speciálních znaků. Ale nevynutí kompatibilitu v případě rozlišování malých/VELKÝCH písmen.",
    "File Management" : "Správa souboru",
    "Home" : "Domů",
    "Target folder does not exist any more" : "Cílová složka už neexistuje",
    "Reload current directory" : "Znovu načíst stávající složku",
    "Go to the \"{dir}\" directory" : "Přejít do složky „{dir}“",
    "Current directory path" : "Stávající popis umístění složky",
    "Your have used your space quota and cannot upload files anymore" : "Využili jste celou svou kvótu na prostor a už nemůžete nahrávat další soubory",
    "You do not have permission to upload or create files here." : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory.",
    "Drag and drop files here to upload" : "Soubory nahrajete jejich přetažením sem",
    "Favorite" : "Oblíbené",
    "Back" : "Zpět",
    "Toggle selection for file \"{displayName}\"" : "Vybrat / zrušit výběr souboru „{displayName}“",
    "Toggle selection for folder \"{displayName}\"" : "Vybrat / zrušit výběr složky „{displayName}“",
    "File is loading" : "Soubor je načítán",
    "Folder is loading" : "Složka se načítá",
    "Filename" : "Soubor",
    "Folder name" : "Název složky",
    "This node is unavailable" : "Tento uzel není k dispozici",
    "Another entry with the same name already exists." : "Už existuje jiná položka se stejným názvem.",
    "Invalid filename." : "Neplatný název souboru.",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Přejmenováno „{oldName}“ na „{newName}",
    "Rename file" : "Přejmenovat soubor",
    "Pending" : "Nevyřízené",
    "Unknown date" : "Neznámé datum",
    "Clear filter" : "Vyčistit filtr",
    "Modified" : "Změněno",
    "Type" : "Typ",
    "Active filters" : "Zapnuté filtry",
    "Remove filter" : "Odebrat filtr",
    "Total rows summary" : "Celkový souhrn řádek",
    "Toggle selection for all files and folders" : "Vybrat / zrušit výběr všech souborů a složek",
    "Name" : "Název",
    "Size" : "Velikost",
    "\"{displayName}\" failed on some elements" : "„{displayName}“ se pro některé prvky nezdařilo",
    "\"{displayName}\" batch action executed successfully" : "hromadná akce „{displayName}“ úspěšně vykonána",
    "\"{displayName}\" action failed" : "akce „{displayName}“ se nezdařila",
    "Actions" : "Akce",
    "(selected)" : "(vybráno)",
    "List of files and folders." : "Seznam souborů a složek.",
    "You have used your space quota and cannot upload files anymore." : "Využili jste celou svou kvótu na prostor a už nemůžete nahrávat další soubory.",
    "Column headers with buttons are sortable." : "Podle těch sloupců, které mají v záhlaví tlačítko, je možné řadit.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Seznam není vykreslen celý z důvodu nároků na výkon. Soubory budou dokreslovány, jak se budete posouvat seznamem.",
    "File not found" : "Soubor nenalezen",
    "{count} selected" : "vybráno {count}",
    "{usedQuotaByte} used" : "{usedQuotaByte} využito",
    "{used} of {quota} used" : "Využito {used} z {quota} ",
    "{relative}% used" : "{relative}% využito",
    "Could not refresh storage stats" : "Nedaří se znovu načíst statistiky úložiště",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložiště je plné – soubory už proto nelze aktualizovat ani synchronizovat!",
    "Storage information" : "Informace o úložišti",
    "Storage quota" : "Kvóta úložiště",
    "New folder" : "Nová složka",
    "Create new folder" : "Vytvořit novou složku",
    "This name is already in use." : "Tento název už je využíván.",
    "Create" : "Vytvořit",
    "Fill template fields" : "Vyplňte kolonky šablony",
    "Submitting fields …" : "Odesílání kolonek…",
    "Submit" : "Odeslat",
    "Choose a file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Transfer" : "Převést",
    "Transfer {path} to {userid}" : "Převést {path} na {userid}",
    "Invalid path selected" : "Vybrán neplatný popis umístění",
    "Unknown error" : "Neznámá chyba",
    "Ownership transfer request sent" : "Žádost o převedení vlastnictví zaslána",
    "Cannot transfer ownership of a file or folder you do not own" : "Není možné převést vlastnictví souboru či složky, kterých nejste vlastníky",
    "Transfer ownership of a file or folder" : "Převést vlastnictví souboru či složky",
    "Choose file or folder to transfer" : "Zvolte soubor nebo složku k převedení",
    "Change" : "Změnit",
    "New owner" : "Nový vlastník",
    "Keep {old}" : "Ponechat {old}",
    "Keep without extension" : "Ponechat bez přípony",
    "Use {new}" : "Použít {new}",
    "Remove extension" : "Odebrat příponu",
    "Change file extension" : "Změnit příponu souboru",
    "Changing the file extension from \"{old}\" to \"{new}\" may render the file unreadable." : "Změna přípony souboru z „{old}“ na „{new}“ může soubor znečitelnit.",
    "Removing the file extension \"{old}\" may render the file unreadable." : "Odebrání přípony souboru „{old}“ může soubor znečitelnit.",
    "Adding the file extension \"{new}\" may render the file unreadable." : "Přidání přípony souboru „{new}“ může soubor znečitelnit.",
    "Do not show this dialog again." : "Nezobrazovat tento dialog znovu.",
    "Select file or folder to link to" : "Vyberte soubor nebo složku na kterou odkazovat",
    "Choose {file}" : "Zvolit {file}",
    "Share" : "Nasdílet",
    "Shared by link" : "Sdíleno pomocí odkazu",
    "Shared" : "Sdíleno",
    "Switch to list view" : "Přepnout do zobrazení v seznamu",
    "Switch to grid view" : "Přepnout do zobrazení v mřížce",
    "The file could not be found" : "Soubor nebylo možné najít",
    "Upload was cancelled by user" : "Odeslání bylo zrušeno uživatelem",
    "Not enough free space" : "Nedostatek volného prostoru",
    "Operation is blocked by access control" : "Operace je blokována řízením přístupu",
    "Error during upload: {message}" : "Chyba při nahrávání: {message}",
    "Error during upload, status code {status}" : "Chyba při nahrávání – stavový kód {status}",
    "Unknown error during upload" : "Neznámá chyba při nahrávání",
    "\"{displayName}\" action executed successfully" : "akce „{displayName}“ úspěšně vykonána",
    "Loading current folder" : "Načítá se stávající složka",
    "Retry" : "Zkusit znovu",
    "No files in here" : "Žádné soubory",
    "Upload some content or sync with your devices!" : "Nahrajte nějaký obsah nebo proveďte synchronizaci se svými zařízeními!",
    "Go back" : "Jít zpět",
    "Filter file names …" : "Filtrovat názvy souborů…",
    "Views" : "Zobrazení",
    "Files settings" : "Nastavení pro Soubory",
    "Your files" : "Vaše soubory",
    "Open in files" : "Otevřít v aplikaci Soubory",
    "File cannot be accessed" : "K souboru se nedaří přistoupit",
    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Soubor se nepodařilo nalézt nebo nemáte oprávnění pro jeho zobrazení – požádejte odesilatele, aby vám ho nasdílel.",
    "Clipboard is not available" : "Schránka není k dispozici",
    "WebDAV URL copied to clipboard" : "WebDAV URL zkopírována do schránky",
    "Sort favorites first" : "Seřadit od oblíbených",
    "Sort folders before files" : "Při řazení zobrazovat složky a pak až soubory",
    "Show hidden files" : "Zobrazit skryté soubory",
    "Crop image previews" : "Oříznout náhledy obrázků",
    "Enable the grid view" : "Zapnout zobrazení v mřížce",
    "Enable folder tree" : "Zapnout strom složek",
    "Additional settings" : "Další nastavení",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Zkopírovat do schránky",
    "Use this address to access your Files via WebDAV" : "Tuto adresu použijte pro přístup k vašim souborům prostřednictvím protokolu WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Pokud jste zapnuli 2FA (dvoufaktorovou autentizaci), je třeba kliknutím sem vytvořit a použít nové heslo pro aplikaci.",
    "Warnings" : "Varování",
    "Prevent warning dialogs from open or reenable them." : "Zabránit dialogům s varováními v otevírání nebo znovupovolení.",
    "Show a warning dialog when changing a file extension." : "Při měnění přípony souboru zobrazit varovný dialog.",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Speed up your Files experience with these quick shortcuts." : "Zrychlete svůj dojem ze Souborů pomocí těchto rychlých zkratek.",
    "Open the actions menu for a file" : "Otevřít nabídku akcí pro soubor",
    "Rename a file" : "Přejmenovat soubor",
    "Delete a file" : "Smazat soubor",
    "Favorite or remove a file from favorites" : "Zařadit mezi oblíbené (nebo odebrat)",
    "Manage tags for a file" : "Spravovat štítky pro soubor",
    "Selection" : "Výběr",
    "Select all files" : "Vybrat všechny soubory",
    "Deselect all files" : "Zrušit výběr všech souborů",
    "Select or deselect a file" : "Vybrat/zrušit výběr souboru",
    "Select a range of files" : "Vybrat rozsah souborů",
    "Navigation" : "Pohyb",
    "Navigate to the parent folder" : "Přejít do nadřazené složky",
    "Navigate to the file above" : "Přejít na soubor výše",
    "Navigate to the file below" : "Přejít na soubor níže",
    "Navigate to the file on the left (in grid mode)" : "Přejít na soubor vlevo (v režimu mřížky)",
    "Navigate to the file on the right (in grid mode)" : "Přejít na soubor vpravo (v režimu mřížky)",
    "View" : "Zobrazit",
    "Toggle the grid view" : "Vyp/zap. zobrazení v mřížce",
    "Open the sidebar for a file" : "Otevřít postranní panel pro soubor",
    "Show those shortcuts" : "Zobrazit tyto zkratky",
    "You" : "Vy",
    "Shared multiple times with different people" : "Nasdílet několikrát různým lidem",
    "Error while loading the file data" : "Chyba při načítání dat souboru",
    "Owner" : "Vlastník",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Add to favorites" : "Přidat do oblíbených",
    "Tags" : "Štítky",
    "Blank" : "Prázdný",
    "Unable to create new file from template" : "Nedaří se vytvořit soubor ze šablony",
    "Pick a template for {name}" : "Vyberte si šablonu pro {name}",
    "Create a new file with the selected template" : "Vytvořit nový soubor ze zvolené šablony",
    "Creating file" : "Vytváření souboru",
    "Save as {displayName}" : "Uložit jako {displayName}",
    "Save as …" : "Uložit jako…",
    "Converting files …" : "Převádění souborů…",
    "Failed to convert files: {message}" : "Nepodařilo se převést soubory: {message}",
    "All files failed to be converted" : "Žádný ze souborů se nepodařilo převést",
    "One file could not be converted: {message}" : "Jeden soubor nebylo možné převést: {message}",
    "_One file could not be converted_::_%n files could not be converted_" : ["Jeden soubor nebylo možné převést","%n soubory nebylo možné převést","%n souborů nebylo možné převést","%n soubory nebylo možné převést"],
    "_One file successfully converted_::_%n files successfully converted_" : ["Jeden soubor úspěšně převeden","%n soubory úspěšně převedeny","%n souborů úspěšně převedeno","%n soubory úspěšně převedeny"],
    "Files successfully converted" : "Soubory úspěšně převedeny",
    "Failed to convert files" : "Nepodařilo se převést soubory",
    "Converting file …" : "Převádění souboru…",
    "File successfully converted" : "Soubor úspěšně převeden",
    "Failed to convert file: {message}" : "Nepodařilo se převést soubor: {message}",
    "Failed to convert file" : "Nepodařilo se převést soubor",
    "Deletion cancelled" : "Mazání zrušeno",
    "Leave this share" : "Opustit toto sdílení",
    "Leave these shares" : "Opustit tato sdílení",
    "Disconnect storage" : "Odpojit úložiště",
    "Disconnect storages" : "Odpojit úložiště",
    "Delete permanently" : "Nevratně smazat",
    "Delete and unshare" : "Smazat a zrušit sdílení",
    "Delete file" : "Smazat soubor",
    "Delete files" : "Smazat soubory",
    "Delete folder" : "Smazat složku",
    "Delete folders" : "Smazat složky",
    "Delete" : "Smazat",
    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["Chystáte se trvale smazat {count} položku","Chystáte se trvale smazat {count} položky","Chystáte se trvale smazat {count} položek","Chystáte se trvale smazat {count} položky"],
    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["Chystáte se smazat {count} položku","Chystáte se smazat {count} položky","Chystáte se smazat {count} položek","Chystáte se smazat {count} položky"],
    "Confirm deletion" : "Potvrdit smazání",
    "Cancel" : "Storno",
    "Moving \"{source}\" to \"{destination}\" …" : "Přesouvání „{source}“ do „{destination}“ …",
    "Copying \"{source}\" to \"{destination}\" …" : "Kopírování „{source}“ do „{destination}“ …",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Není možné přesunout soubor/složku do sebe samé nebo do své vlastní podložky",
    "(copy)" : "(zkopírovat)",
    "(copy %n)" : "(zkopírovat %n)",
    "Move cancelled" : "Přesunutí zrušeno",
    "A file or folder with that name already exists in this folder" : "V této složce už existuje stejnojmenný soubor či složka",
    "The files are locked" : "Soubory jsou zamknuty",
    "The file does not exist anymore" : "Soubor už neexistuje",
    "Choose destination" : "Vyberte cíl",
    "Copy to {target}" : "Zkopírovat do {target}",
    "Copy" : "Kopírovat",
    "Move to {target}" : "Přesunout do {target}",
    "Move" : "Přesunout",
    "Move or copy operation failed" : "Operace přesunu či zkopírování se nezdařila",
    "Move or copy" : "Přesunout nebo zkopírovat",
    "Cancelled move or copy of \"{filename}\"." : "Přesunutí nebo zkopírování „{filename}“ zrušeno.",
    "Cancelled move or copy operation" : "Operace přesunutí či zkopírování zrušena",
    "Open folder {displayName}" : "Otevřít složku {displayName}",
    "Open in Files" : "Otevřít v Souborech",
    "Open file locally" : "Otevřít soubor lokálně",
    "The file should now open on your device. If it doesn't, please check that you have the desktop app installed." : "Soubor by se nyní měl otevřít na vašem zařízení. Pokud ne, zkontrolujte, zda máte nainstalovanou desktopovou aplikaci.",
    "Retry and close" : "Zkusit znovu a zavřít",
    "Open online" : "Otevřít online",
    "Failed to redirect to client" : "Nepodařilo se přesměrovat klienta",
    "Open locally" : "Otevřít lokálně",
    "Rename" : "Přejmenovat",
    "Open details" : "Otevřít podrobnosti",
    "View in folder" : "Zobrazit ve složce",
    "Today" : "Dnes",
    "Last 7 days" : "Uplynulých 7 dnů",
    "Last 30 days" : "Uplynulých 30 dnů",
    "This year ({year})" : "Tento rok ({year})",
    "Last year ({year})" : "Minulý rok ({year})",
    "Documents" : "Dokumenty",
    "Spreadsheets" : "Tabulky",
    "Presentations" : "Prezentace",
    "PDFs" : "PDF dokumenty",
    "Folders" : "Složky",
    "Audio" : "Zvuk",
    "Photos and images" : "Fotky a obrázky",
    "Videos" : "Videa",
    "New folder creation cancelled" : "Vytváření nové složky zrušeno",
    "Created new folder \"{name}\"" : "Vytvořena nová složka „{name}“",
    "Unable to initialize the templates directory" : "Nepodařilo se vytvořit složku pro šablony",
    "Create templates folder" : "Vytvořit složku pro šablony",
    "Templates" : "Šablony",
    "New template folder" : "Nová složka šablon",
    "In folder" : "Ve složce",
    "Search in folder: {folder}" : "Hledat ve složce: {folder}",
    "One of the dropped files could not be processed" : "Jeden z přetažených souborů se nepodařilo zpracovat",
    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Vámi využívaný prohlížeč nepodporuje aplikační program. rozhraní pro přístup k souborovému systému (Filesytem API). Složky nebudou nahrány",
    "No files to upload" : "Žádné soubory k nahrání",
    "Unable to create the directory {directory}" : "Nepodařilo se vytvořit složku {directory}",
    "Some files could not be uploaded" : "Některé soubory nebylo možné nahrát",
    "Files uploaded successfully" : "Soubor úspěšně nahrán",
    "No files to process" : "Žádné soubory ke zpracování",
    "Some files could not be copied" : "Některé soubory nebylo možné zkopírovat",
    "Some files could not be moved" : "Některé soubory nebylo možné přesunout",
    "Files copied successfully" : "Soubory úspěšně zkopírovány",
    "Files moved successfully" : "Soubory úspěšně přesunuty",
    "Conflicts resolution skipped" : "Řešení kolizí přeskočeno",
    "Upload cancelled" : "Nahrávání zrušeno",
    "This operation is forbidden" : "Tato operace je zakázána",
    "This directory is unavailable, please check the logs or contact the administrator" : "Tento adresář není dostupný, zkontrolujte záznamy událostí nebo se obraťte na správce",
    "Storage is temporarily not available" : "Úložiště je dočasně nedostupné",
    "Unexpected error: {error}" : "Neočekávaná chyby: {error}",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} složka","{folderCount} složky","{folderCount} složek","{folderCount} složky"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} soubor","{fileCount} soubory","{fileCount} souborů","{fileCount} soubory"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 soubor a {folderCount} složka","1 soubor a {folderCount} složky","1 soubor a {folderCount} složek","1 soubor a {folderCount} složky"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} soubor a 1 složka","{fileCount} soubory a 1 složka","{fileCount} souborů a 1 složka","{fileCount} soubory a 1 složka"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} souborů a {folderCount} složek",
    "Filename must not be empty." : "Je třeba vyplnit název souboru.",
    "\"{char}\" is not allowed inside a filename." : "„{char}“ není v názvu souboru možné použít.",
    "\"{segment}\" is a reserved name and not allowed for filenames." : "„{segment}“ je vyhrazeným názvem a není povoleno k použití pro názvy souborů.",
    "\"{extension}\" is not an allowed filetype." : "„{extension}“ není povoleným typem souboru.",
    "Filenames must not end with \"{extension}\"." : "Je třeba, aby názvy souborů nekončily na „{extension}“.",
    "List of favorite files and folders." : "Seznam oblíbených souborů a složek.",
    "No favorites yet" : "Zatím nic oblíbeného",
    "Files and folders you mark as favorite will show up here" : "Zde budou zobrazeny soubory a složky, které označíte jako oblíbené",
    "All files" : "Všechny soubory",
    "List of your files and folders." : "Seznam vašich souborů a složek.",
    "All folders" : "Všechny složky",
    "Personal files" : "Osobní soubory",
    "List of your files and folders that are not shared." : "Seznam vašich souborů a složek, které nejsou sdíleny.",
    "No personal files found" : "Nenalezeny žádné osobní soubory",
    "Files that are not shared will show up here." : "Soubory, které nejsou nikomu sdíleny se zobrazí zde.",
    "Recent" : "Nedávné",
    "List of recently modified files and folders." : "Seznam nedávno změněných souborů a složek.",
    "No recently modified files" : "Žádné nedávno změněné soubory.",
    "Files and folders you recently modified will show up here." : "Zde budou zobrazeny soubory a složky, které jste nedávno změnili.",
    "No entries found in this folder" : "V této složce nebylo nic nalezeno",
    "Select all" : "Vybrat vše",
    "Upload too large" : "Nahrávaná data jsou příliš objemná",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Soubory, které se snažíte nahrát, překračují limit velikosti nahrávání na tomto serveru.",
    "File could not be found" : "Soubor se nedaří nalézt",
    "Download" : "Stáhnout",
    "Show list view" : "Zobrazit v seznamu",
    "Show grid view" : "Zobrazit v mřížce",
    "Close" : "Zavřít",
    "Could not create folder \"{dir}\"" : "Složku „{dir}“ nelze vytvořit",
    "This will stop your current uploads." : "Toto zastaví stávající nahrávání.",
    "Upload cancelled." : "Nahrávání zrušeno.",
    "Processing files …" : "Zpracovávání souborů…",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Soubor {filename} nelze nahrát, protože je to buď adresář nebo má velikost nula bajtů",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nedostatek volného místa pro uložení – velikost nahrávaných dat je {size1}, volné kapacity úložiště ale zbývá už jen {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cílová složka „{dir}“ už neexistuje",
    "An unknown error has occurred" : "Vyskytla se neznámá chyba",
    "File could not be uploaded" : "Soubor se nepodařilo nahrát",
    "Uploading …" : "Nahrávání…",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Nahrávání… ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrání této položky není podporováno",
    "Error when assembling chunks, status code {status}" : "Chyba při kompletaci shluků, kód chyby {status}",
    "Choose target folder" : "Zvolte cílovou složku",
    "Set reminder" : "Nastavit připomínku",
    "Edit locally" : "Upravit lokálně",
    "Open" : "Otevřít",
    "Could not load info for file \"{file}\"" : "Nepodařilo se načíst informace pro soubor „{file}“",
    "Details" : "Podrobnosti",
    "Please select tag(s) to add to the selection" : "Vyberte štítky které přidat do výběru",
    "Apply tag(s) to selection" : "Uplatnit štítky na výběr",
    "Select directory \"{dirName}\"" : "Vybrat složku „{dirName}“",
    "Select file \"{fileName}\"" : "Vybrat soubor „{fileName}“",
    "Unable to determine date" : "Nelze určit datum",
    "Could not move \"{file}\", target exists" : "„{file}“ nelze přesunout – cíl už existuje",
    "Could not move \"{file}\"" : "„{file}“ nelze přesunout",
    "copy" : "kopie",
    "Could not copy \"{file}\", target exists" : "Nelze kopírovat „{file}“, cíl už existuje",
    "Could not copy \"{file}\"" : "Nelze kopírovat „{file}“",
    "Copied {origin} inside {destination}" : "{origin} zkopírován do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "{origin} a {nbfiles} dalších souborů zkopírováno do {destination}",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "„{fileName}“ nelze přejmenovat – už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Název „{targetName}“ je už použitý ve složce „{dir}“. Zvolte jiný název.",
    "Could not rename \"{fileName}\"" : "„{fileName}“ nelze přejmenovat",
    "Could not create file \"{file}\"" : "Soubor „{file}“ nelze vytvořit",
    "Could not create file \"{file}\" because it already exists" : "Soubor „{file}“ nelze vytvořit, protože zde už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Složku „{dir}“ nelze vytvořit, protože už existuje",
    "Could not fetch file details \"{file}\"" : "Nedaří se získat podrobnosti o souboru „{file}“",
    "Error deleting file \"{fileName}\"." : "Chyba při mazání souboru „{fileName}“.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žádné výsledky hledání v ostatních složkách pro {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Pokud chcete hledat v ostatních složkách, zadejte více než dva znaky",
    "_%n folder_::_%n folders_" : ["%n složka","%n složky","%n složek","%n složky"],
    "_%n file_::_%n files_" : ["%n soubor","%n soubory","%n souborů","%n soubory"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["včetně %n skrytého","včetně %n skrytých","včetně %n skrytých","včetně %n skrytých"],
    "You do not have permission to upload or create files here" : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrává se %n soubor","Nahrávají se %n soubory","Nahrává se %n souborů","Nahrávají se %n soubory"],
    "New" : "Nové",
    "New file/folder menu" : "Nabídka souboru/složky",
    "Select file range" : "Vybrat rozsah souborů",
    "{used}%" : "{used}%",
    "{used} used" : "{used} využito",
    "\"{name}\" is an invalid file name." : "„{name}“ není platným názvem souboru.",
    "File name cannot be empty." : "Je třeba vyplnit název souboru.",
    "\"/\" is not allowed inside a file name." : "„/“ není povolený znak v názvu souboru.",
    "\"{name}\" is not an allowed filetype" : "„{name}“ není povolený typ souboru",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Úložiště uživatele {owner} je zaplněné – nelze aktualizovat ani synchronizovat soubory!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Skupinová složka „{mountPoint}“ je plná, soubory už nadále není možné aktualizovat nebo synchronizovat!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externí úložiště „{mountPoint}“ je plné, soubory už nadále není možné aktualizovat nebo synchronizovat!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Vaše úložiště je plné – nelze aktualizovat ani synchronizovat soubory!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Úložiště {owner} je téměř plné ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Skupinová složka „{mountPoint}“ je téměř plná ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externí úložiště „{mountPoint}“ je téměř plné ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložiště je téměř plné ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["shoduje se s „{filter}“","shodují se s „{filter}“","shoduje se s „{filter}“","shodují se s „{filter}“"],
    "Direct link was copied (only works for people who have access to this file/folder)" : "Přímý odkaz byl zkopírován (funguje pouze pro osoby, které mají přístup k tomuto souboru/složce)",
    "Path" : "Popis umístění",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtů","%n bajty"],
    "Favorited" : "Přidáno mezi oblíbené",
    "Copy direct link (only works for people who have access to this file/folder)" : "Zkopírovat přímý odkaz (funguje pouze pro osoby, které mají přístup k tomuto souboru/složce)",
    "Upload file" : "Nahrát soubor",
    "Not favorited" : "Nepřidáno do oblíbených",
    "An error occurred while trying to update the tags" : "Při pokusu o úpravu štítků došlo k chybě",
    "You don't have permission to upload or create files here." : "Nemáte oprávnění sem nahrávat nebo zde vytvářet soubory.",
    "Storage informations" : "Informace o úložišti",
    "Choose file" : "Vyberte soubor",
    "Go to the previous folder" : "Přejít do předchozí složky",
    "Open the files app settings" : "Otevřít nastavení aplikace soubory",
    "Unable to change the favourite state of the file" : "Nedaří se změnit stav „oblíbené“ souboru",
    "Edit file locally" : "Upravit soubor lokálně",
    "Edit online" : "Upravit online",
    "Create new templates folder" : "Vytvořit novou složku šablon",
    "List of favorites files and folders." : "Seznam oblíbených souborů a složek.",
    "Personal Files" : "Osobní soubory",
    "Text file" : "Textový soubor",
    "New text file.txt" : "Nový textový soubor.txt",
    "Favored" : "Zařazeno mezi oblíbené",
    "Favor" : "Zařadit mezi oblíbené",
    "Not favored" : "Není v oblíbených",
    "Submitting fields…" : "Odesílání kolonek…",
    "Filter filenames…" : "Filtrovat názvy souborů…",
    "{count} files could not be converted" : "{count} souborů nebylo možné převést",
    "{count} files successfully converted" : "{count} souborů úspěšně převedeno"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
